@@ -64,7 +64,6 @@ def test_print():
     assert '1.0' in text
 
 
-@remove_files('sine.png', 'sine-cosine.png')
 def test_file_plots():
     kernel = get_kernel(GnuplotKernel)
     kernel.call_magic('%gnuplot pngcairo size 560, 420')
@@ -87,6 +86,8 @@ def test_file_plots():
     kernel.do_execute(code)
     assert os.path.exists('sine-cosine.png')
 
+    remove_files('sine.png', 'sine-cosine.png')
+
 
 def test_inline_plots():
     kernel = get_kernel(GnuplotKernel)
@@ -205,9 +206,49 @@ def test_bad_prompt():
     assert 'warning' in text.lower()
 
 
+def test_data_block():
+    kernel = get_kernel(GnuplotKernel)
+
+    # Good data block
+    code = """
+$DATA << EOD
+# x y
+1 1
+2 2
+3 3
+4 4
+EOD
+plot $DATA
+    """
+    kernel.do_execute(code)
+    text = get_log_text(kernel)
+    assert text.count('Display Data') == 1
+    clear_log_text(kernel)
+
+    # Badly terminated data block
+    bad_code = """
+$DATA << EOD
+# x y
+1 1
+2 2
+3 3
+4 4
+EODX
+plot $DATA
+    """
+    kernel.do_execute(bad_code)
+    text = get_log_text(kernel)
+    assert 'Error' in text
+    clear_log_text(kernel)
+
+    # Good code should work after the bad_code
+    kernel.do_execute(code)
+    text = get_log_text(kernel)
+    assert text.count('Display Data') == 1
+
+
 # magics #
 
-@remove_files('cosine.png')
 def test_cell_magic():
     # To simulate '%load_ext gnuplot_kernel';
     # create a main kernel, a gnuplot kernel and
@@ -239,8 +280,9 @@ def test_cell_magic():
     assert os.path.exists('cosine.png')
     clear_log_text(kernel)
 
+    remove_files('cosine.png')
+
 
-@remove_files('sine+cosine.png')
 def test_reset_cell_magic():
     kernel = get_kernel(GnuplotKernel)
 
@@ -258,6 +300,8 @@ def test_reset_cell_magic():
     kernel.do_execute(code)
     assert os.path.exists('sine+cosine.png')
 
+    remove_files('sine+cosine.png')
+
 
 def test_reset_line_magic():
     kernel = get_kernel(GnuplotKernel)
@@ -285,24 +329,19 @@ def test_reset_line_magic():
 
 
 # fixture tests #
-temp_file = 'antigravity.txt'
-
-
-@remove_files(temp_file)
-def test_create_file():
+def test_remove_files():
     """
     This test create a file. Next test tests that it
     is deleted
     """
+    filename = 'antigravit.txt'
     # Create file
-    with open(temp_file, 'w'):
+    # make sure it exis
+    with open(filename, 'w'):
         pass
 
-    assert os.path.exists(temp_file)
+    assert os.path.exists(filename)
 
+    remove_files(filename)
 
-def test_remove_files():
-    """
-    Check that file created in previous test is gone
-    """
-    assert not os.path.exists(temp_file)
+    assert not os.path.exists(filename)
